@@ -19,7 +19,6 @@
  ***************************************************************************/
 
 #include "PrinterDescription.h"
-
 #include "ui_PrinterDescription.h"
 
 #include <KCupsPrinter.h>
@@ -29,8 +28,9 @@
 #include <QDBusMessage>
 #include <QProgressBar>
 #include <QLabel>
-
 #include <QDBusConnection>
+
+#include <KToolInvocation>
 #include <KMenu>
 #include <KDebug>
 
@@ -69,6 +69,9 @@ PrinterDescription::PrinterDescription(QWidget *parent) :
     ui->actionCleanPrintHeads->setVisible(false);
     ui->actionPrintSelfTestPage->setVisible(false);
     ui->maintenancePB->setMenu(menu);
+
+    ui->errorMessage->setMessageType(KMessageWidget::Error);
+    ui->errorMessage->hide();
 }
 
 PrinterDescription::~PrinterDescription()
@@ -78,14 +81,9 @@ PrinterDescription::~PrinterDescription()
 
 void PrinterDescription::on_openQueuePB_clicked()
 {
-    QDBusMessage message;
-    message = QDBusMessage::createMethodCall(QLatin1String("org.kde.PrintQueue"),
-                                             QLatin1String("/"),
-                                             QLatin1String("org.kde.PrintQueue"),
-                                             QLatin1String("ShowQueue"));
-    // Use our own cached tid to avoid crashes
-    message << qVariantFromValue(m_destName);
-    QDBusConnection::sessionBus().send(message);
+    QStringList args;
+    args << m_destName;
+    KToolInvocation::kdeinitExec(QLatin1String("kde-print-queue"), args);
 }
 
 void PrinterDescription::on_defaultCB_clicked()
@@ -121,7 +119,7 @@ void PrinterDescription::setPrinterIcon(const QIcon &icon)
     ui->iconL->setPixmap(icon.pixmap(PRINTER_ICON_SIZE, PRINTER_ICON_SIZE));
 }
 
-void PrinterDescription::setDestName(const QString &name, const QString &description, bool isClass)
+void PrinterDescription::setDestName(const QString &name, const QString &description, bool isClass, bool singlePrinter)
 {
     m_destName = name;
 
@@ -131,17 +129,21 @@ void PrinterDescription::setDestName(const QString &name, const QString &descrip
         ui->sharedCB->setText(m_isClass ? i18n("Share this class") : i18n("Share this printer"));
     }
 
+    ui->nameMsgL->setText(name);
     if (!description.isEmpty() && description != ui->printerNameL->text()) {
         ui->printerNameL->setText(description);
     } else if (description.isEmpty() && name != ui->printerNameL->text()) {
         ui->printerNameL->setText(name);
     }
+
+    ui->statusL->setVisible(singlePrinter);
+    ui->nameL->setVisible(singlePrinter);
+    ui->nameMsgL->setVisible(singlePrinter);
 }
 
 void PrinterDescription::setDestStatus(const QString &status)
 {
-  ui->statusL->setText(status);
-  ui->statusL->setVisible(!status.isEmpty());
+    ui->statusL->setText(status);
 }
 
 void PrinterDescription::setLocation(const QString &location)
@@ -261,6 +263,8 @@ void PrinterDescription::requestFinished()
 {
     KCupsRequest *request = qobject_cast<KCupsRequest*>(sender());
     if (request && request->hasError()) {
+        ui->errorMessage->setText(i18n("Failed to perform request: %1", request->errorMsg()));
+        ui->errorMessage->animatedShow();
         emit updateNeeded();
     }
 }
